@@ -3,29 +3,34 @@ import shutil
 import tempfile
 import unittest
 
-from handwrite.sheettopng import SheetToPNG, ALL_CHARS
+from handwrite.sheettopng import SHEETtoPNG, ALL_CHARS
 
 
-class TestSheetToPNG(unittest.TestCase):
+class TestSHEETtoPNG(unittest.TestCase):
     def setUp(self):
         self.directory = tempfile.mkdtemp()
         self.sheets_path = os.path.join(
             os.path.dirname(os.path.abspath(__file__)),
             "test_data" + os.sep + "sheettopng",
         )
-        self.converter = SheetToPNG()
+        self.converter = SHEETtoPNG()
 
     def tearDown(self):
         shutil.rmtree(self.directory)
 
     def test_convert(self):
+        # Single sheet input
         excellent_scan = os.path.join(self.sheets_path, "excellent.jpg")
-        self.converter.convert(excellent_scan, self.directory)
+        config = os.path.join(
+            os.path.dirname(os.path.abspath(__file__)),
+            "test_data",
+            "config_data",
+            "default.json",
+        )
+        self.converter.convert(excellent_scan, self.directory, config)
         for i in ALL_CHARS:
             self.assertTrue(
-                os.path.exists(
-                    os.path.join(self.directory, f"{i}" + os.sep + f"{i}.png")
-                )
+                os.path.exists(os.path.join(self.directory, f"{i}", f"{i}.png"))
             )
 
     # TODO Once all the errors are done for detect_characters
